==> zio-aws-lightsail_2.12-5.17.172.1-sources.jar: zio/aws/lightsail/model/RelationalDatabaseEndpoint.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{NonEmptyString, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RelationalDatabaseEndpoint(
    port: Optional[Integer] = Optional.Absent,
    address: Optional[NonEmptyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint = {
    import RelationalDatabaseEndpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
      .builder()
      .optionallyWith(port.map(value => value: java.lang.Integer))(_.port)
      .optionallyWith(
        address.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.address)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.RelationalDatabaseEndpoint.ReadOnly =
    zio.aws.lightsail.model.RelationalDatabaseEndpoint.wrap(buildAwsValue())
}
object RelationalDatabaseEndpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.RelationalDatabaseEndpoint =
      zio.aws.lightsail.model.RelationalDatabaseEndpoint(
        port.map(value => value),
        address.map(value => value)
      )
    def port: Optional[Integer]
    def address: Optional[NonEmptyString]
    def getPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("port", port)
    def getAddress: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("address", address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
  ) extends zio.aws.lightsail.model.RelationalDatabaseEndpoint.ReadOnly {
    override val port: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.port())
      .map(value => value: Integer)
    override val address: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.address())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
  ): zio.aws.lightsail.model.RelationalDatabaseEndpoint.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/RelationalDatabaseEndpoint.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.{NonEmptyString, Integer}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RelationalDatabaseEndpoint(
    port: Option[Integer] = None,
    address: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint = {
    import RelationalDatabaseEndpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
      .builder()
      .optionallyWith(
        port.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.port)
      .optionallyWith(
        address.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.address)
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.RelationalDatabaseEndpoint.ReadOnly =
    zio.aws.lightsail.model.RelationalDatabaseEndpoint.wrap(buildAwsValue())
}
object RelationalDatabaseEndpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.RelationalDatabaseEndpoint =
      zio.aws.lightsail.model.RelationalDatabaseEndpoint(
        port.map(value => value),
        address.map(value => value)
      )
    def port: Option[Integer]
    def address: Option[NonEmptyString]
    def getPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("port", port)
    def getAddress: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("address", address)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
  ) extends zio.aws.lightsail.model.RelationalDatabaseEndpoint.ReadOnly {
    override val port: Option[Integer] = scala
      .Option(impl.port())
      .map(value => zio.aws.lightsail.model.primitives.Integer(value))
    override val address: Option[NonEmptyString] = scala
      .Option(impl.address())
      .map(value => zio.aws.lightsail.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.RelationalDatabaseEndpoint
  ): zio.aws.lightsail.model.RelationalDatabaseEndpoint.ReadOnly = new Wrapper(
    impl
  )
}
